#if defined HAVE_LOCALE_H && defined HAVE_SETLOCALE && defined HAVE_LANGINFO_H && defined HAVE_MBSTOWCS
#define LOCALE_MONTHNAMES
#endif
#if defined HAVE_LOCALE_H && defined HAVE_SETLOCALE && defined HAVE_WCSXFRM
#define LOCALE_SORT_ORDER
#endif
#if defined HAVE_LOCALE_H && defined HAVE_SETLOCALE && defined HAVE_LIBINTL_H
#define LOCALE_GETTEXT
#endif

#if defined USEUNINUMOK && defined HAVE_UNINUM_NSDEFS_H && defined HAVE_UNINUM_UNINUM_H
#define USE_UNINUM
#endif

